@@ -38,9 +38,6 @@ pub use self::breaks::BreakModule;
 mod dispatch;
 pub use self::dispatch::DispatchModule;
 
-mod order;
-pub use self::order::OrderModule;
-
 mod reloads;
 pub use self::reloads::ReloadMultiTrip;
 
