@@ -17,7 +17,7 @@ use self::objective_reader::create_objective;
 use crate::constraints::*;
 use crate::extensions::{get_route_modifier, OnlyVehicleActivityCost};
 use crate::format::coord_index::CoordIndex;
-use crate::format::problem::{deserialize_matrix, deserialize_problem, Matrix};
+use crate::format::problem::{deserialize_matrix, deserialize_problem, get_job_tasks, Matrix};
 use crate::format::*;
 use crate::utils::get_approx_transportation;
 use crate::validation::ValidationContext;
@@ -111,7 +111,7 @@ pub struct ProblemProperties {
     has_unreachable_locations: bool,
     has_dispatch: bool,
     has_reloads: bool,
-    has_priorities: bool,
+    has_order: bool,
     has_area_limits: bool,
     has_tour_size_limits: bool,
     max_job_value: Option<f64>,
@@ -137,7 +137,7 @@ fn create_approx_matrices(problem: &ApiProblem) -> Vec<Matrix> {
         .profiles
         .iter()
         .map(move |profile| {
-            let speed = profile.speed.clone().unwrap_or(DEFAULT_SPEED);
+            let speed = profile.speed.unwrap_or(DEFAULT_SPEED);
             let idx =
                 speeds.iter().position(|s| compare_floats(*s, speed) == Equal).expect("Cannot find profile speed");
 
@@ -234,6 +234,11 @@ fn create_constraint_pipeline(
     limits: TravelLimitFunc,
 ) -> ConstraintPipeline {
     let mut constraint = ConstraintPipeline::default();
+
+    if props.has_unreachable_locations {
+        constraint.add_module(Box::new(ReachableModule::new(transport.clone(), REACHABLE_CONSTRAINT_CODE)));
+    }
+
     constraint.add_module(Box::new(TransportConstraintModule::new(
         transport.clone(),
         activity.clone(),
@@ -257,18 +262,10 @@ fn create_constraint_pipeline(
         constraint.add_module(Box::new(DispatchModule::new(DISPATCH_CONSTRAINT_CODE)));
     }
 
-    if props.has_priorities {
-        constraint.add_module(Box::new(OrderModule::new(PRIORITY_CONSTRAINT_CODE)));
-    }
-
     if !locks.is_empty() {
         constraint.add_module(Box::new(StrictLockingModule::new(fleet, locks, LOCKING_CONSTRAINT_CODE)));
     }
 
-    if props.has_unreachable_locations {
-        constraint.add_module(Box::new(ReachableModule::new(transport.clone(), REACHABLE_CONSTRAINT_CODE)));
-    }
-
     if props.has_tour_size_limits {
         add_tour_size_module(&mut constraint)
     }
@@ -389,7 +386,14 @@ fn get_problem_properties(api_problem: &ApiProblem, matrices: &[Matrix]) -> Prob
         .iter()
         .any(|t| t.shifts.iter().any(|s| s.reloads.as_ref().map_or(false, |reloads| !reloads.is_empty())));
 
-    let has_priorities = api_problem.plan.jobs.iter().filter_map(|job| job.order).any(|priority| priority > 1);
+    let has_order = api_problem
+        .plan
+        .jobs
+        .iter()
+        .flat_map(get_job_tasks)
+        .filter_map(|job_task| job_task.order)
+        .any(|order| order > 0);
+
     let has_area_limits = api_problem
         .fleet
         .vehicles
@@ -405,7 +409,7 @@ fn get_problem_properties(api_problem: &ApiProblem, matrices: &[Matrix]) -> Prob
         has_unreachable_locations,
         has_dispatch,
         has_reloads,
-        has_priorities,
+        has_order,
         has_area_limits,
         has_tour_size_limits,
         max_job_value,
