@@ -306,10 +306,8 @@ fn can_consider_departure_rescheduling() {
     };
     let matrix = create_matrix_from_problem(&problem);
 
-    let solution = solve_with_cheapest_insertion(problem, Some(vec![matrix]));
+    let solution = solve_with_metaheuristic_and_iterations(problem, Some(vec![matrix]), 1000);
 
-    assert_eq!(
-        solution.violations,
-        Some(vec![Violation::Break { vehicle_id: "my_vehicle_1".to_string(), shift_index: 0 }])
-    );
+    assert!(solution.violations.is_none());
+    assert!(solution.unassigned.is_none());
 }
